@@ -28,11 +28,12 @@ from __future__ import print_function, division
 
 
 __author__ = "Jérôme Kieffer"
-__date__ = "28/11/2016"
+__date__ = "01/09/2017"
 __license__ = "MIT"
-__copyright__ = "2012-2016 European Synchrotron Radiation Facility, Grenoble, France"
+__copyright__ = "2012-2017 European Synchrotron Radiation Facility, Grenoble, France"
 
 
+from collections import OrderedDict
 import json
 import sys
 import time
@@ -212,7 +213,7 @@ class Bench(object):
         self.LIMIT = 8
         self.repeat = repeat
         self.nbr = nbr
-        self.results = {}
+        self.results = OrderedDict()
         self.meth = []
         self._cpu = None
         self.fig = None
@@ -334,7 +335,7 @@ class Bench(object):
             print("Working on processor: %s" % self.get_cpu())
             label = "1D_" + self.LABELS[method]
             memory_error = (MemoryError, RuntimeError)
-        results = {}
+        results = OrderedDict()
         first = True
         for param in ds_list:
             self.update_mp()
@@ -355,17 +356,24 @@ class Bench(object):
                 break
             self.update_mp()
             if check:
-                if "lut" in method:
+                module = sys.modules.get(AzimuthalIntegrator.__module__)
+                if module:
+                    if "lut" in method:
+                        key = module.EXT_LUT_ENGINE
+                    elif "csr" in method:
+                        key = module.EXT_CSR_ENGINE
+                    else:
+                        key = None
+                if key and module:
                     try:
-                        print("lut: shape= %s \t nbytes %.3f MB " % (bench_test.ai._lut_integrator.lut.shape, bench_test.ai._lut_integrator.lut_nbytes / 2 ** 20))
+                        integrator = bench_test.ai.engines.get(key).engine
                     except MemoryError as error:
                         print(error)
-                elif "csr" in method:
-                    try:
-                        print("csr: size= %s \t nbytes %.3f MB " % (bench_test.ai._csr_integrator.data.size, bench_test.ai._csr_integrator.lut_nbytes / 2 ** 20))
-                    except MemoryError as error:
-                        print(error)
-
+                    else:
+                        if "lut" in method:
+                            print("lut: shape= %s \t nbytes %.3f MB " % (integrator.lut.shape, integrator.lut_nbytes / 2 ** 20))
+                        else:
+                            print("csr: size= %s \t nbytes %.3f MB " % (integrator.data.size, integrator.lut_nbytes / 2 ** 20))
             bench_test.clean()
             self.update_mp()
             try:
@@ -434,7 +442,7 @@ class Bench(object):
             label = "2D_" + self.LABELS[method]
             memory_error = (MemoryError, RuntimeError)
 
-        results = {}
+        results = OrderedDict()
         first = True
         for param in ds_list:
             self.update_mp()
@@ -453,7 +461,25 @@ class Bench(object):
                 break
             self.update_mp()
             if check:
-                print("lut.shape= %s \t lut.nbytes %.3f MB " % (bench_test.ai._lut_integrator.lut.shape, bench_test.ai._lut_integrator.size * 8.0 / 1e6))
+                module = sys.modules.get(AzimuthalIntegrator.__module__)
+                if module:
+                    if "lut" in method:
+                        key = module.EXT_LUT_ENGINE
+                    elif "csr" in method:
+                        key = module.EXT_CSR_ENGINE
+                    else:
+                        key = None
+                if key and module:
+                    try:
+                        integrator = bench_test.ai.engines.get(key).engine
+                    except MemoryError as error:
+                        print(error)
+                    else:
+                        if "lut" in method:
+                            print("lut: shape= %s \t nbytes %.3f MB " % (integrator.lut.shape, integrator.lut_nbytes / 2 ** 20))
+                        else:
+                            print("csr: size= %s \t nbytes %.3f MB " % (integrator.data.size, integrator.lut_nbytes / 2 ** 20))
+
             bench_test.ai.reset()
             bench_test.clean()
             try:
@@ -485,7 +511,7 @@ class Bench(object):
         if ocl is None or not ocl.select_device(devicetype):
             print("No pyopencl or no such device: skipping benchmark")
             return
-        results = {}
+        results = OrderedDict()
         label = "Forward_OpenCL_%s_%s_bits" % (devicetype, ("64" if useFp64 else"32"))
         first = True
         for param in ds_list:
@@ -654,14 +680,14 @@ class Bench(object):
 def run_benchmark(number=10, repeat=1, memprof=False, max_size=1000,
                   do_1d=True, do_2d=False, devices="all"):
     """Run the integrated benchmark using the most common algorithms (method parameter)
-    
+
     :param number: Measure timimg over number of executions
     :param repeat: number of measurement, takes the best of them
     :param memprof: set to True to enable memory profiling to hunt memory leaks
     :param max_size: maximum image size in megapixel, set it to 2 to speed-up the tests.
     :param do_1d: perfrom benchmarking using integrate1d
-    :param do_2d: perfrom benchmarking using integrate2d  
-    :devices: "all", "cpu", "gpu" or "acc" or a list of devices [(proc_id, dev_id)] 
+    :param do_2d: perfrom benchmarking using integrate2d
+    :devices: "all", "cpu", "gpu" or "acc" or a list of devices [(proc_id, dev_id)]
     """
     print("Averaging over %i repetitions (best of %s)." % (number, repeat))
     bench = Bench(number, repeat, memprof, max_size=max_size)
