@@ -8,27 +8,34 @@
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
+
+"""Module used to perform the geometric refinement of the model
+"""
 
 from __future__ import print_function, division, absolute_import
 
 __author__ = "Jerome Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
-__license__ = "GPLv3+"
+__license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "27/10/2016"
+__date__ = "01/06/2017"
 __status__ = "development"
 
 import os
@@ -39,7 +46,8 @@ import numpy
 import types
 from math import pi
 from . import azimuthalIntegrator
-from .calibrant import Calibrant, ALL_CALIBRANTS
+from .calibrant import Calibrant, CALIBRANT_FACTORY
+from .utils.ellipse import fit_ellipse
 AzimuthalIntegrator = azimuthalIntegrator.AzimuthalIntegrator
 from scipy.optimize import fmin, leastsq, fmin_slsqp
 try:
@@ -64,7 +72,7 @@ ROCA = "/opt/saxs/roca"
 
 
 class GeometryRefinement(AzimuthalIntegrator):
-    def __init__(self, data, dist=1, poni1=None, poni2=None,
+    def __init__(self, data=None, dist=1, poni1=None, poni2=None,
                  rot1=0, rot2=0, rot3=0,
                  pixel1=None, pixel2=None, splineFile=None, detector=None,
                  wavelength=None, calibrant=None):
@@ -87,10 +95,13 @@ class GeometryRefinement(AzimuthalIntegrator):
         :param calibrant: instance of pyFAI.calibrant.Calibrant containing the d-Spacing
 
         """
-        self.data = numpy.array(data, dtype=numpy.float64)
-        assert self.data.ndim == 2
-        assert self.data.shape[1] in [3, 4]  # 3 for non weighted, 4 for weighted refinement
-        assert self.data.shape[0] > 0
+        if data is None:
+            self.data = None
+        else:
+            self.data = numpy.array(data, dtype=numpy.float64)
+            assert self.data.ndim == 2
+            assert self.data.shape[1] in [3, 4]  # 3 for non weighted, 4 for weighted refinement
+            assert self.data.shape[0] > 0
 
         if (pixel1 is None) and (pixel2 is None) and (splineFile is None) and (detector is None):
             raise RuntimeError("Setting up the geometry refinement without knowing the detector makes little sense")
@@ -104,8 +115,8 @@ class GeometryRefinement(AzimuthalIntegrator):
             if isinstance(calibrant, Calibrant):
                 self.calibrant = calibrant
             elif type(calibrant) in types.StringTypes:
-                if calibrant in ALL_CALIBRANTS:
-                    self.calibrant = ALL_CALIBRANTS[calibrant]
+                if calibrant in CALIBRANT_FACTORY:
+                    self.calibrant = CALIBRANT_FACTORY(calibrant)
                 else:
                     self.calibrant = Calibrant(filename=calibrant)
             else:
@@ -134,8 +145,9 @@ class GeometryRefinement(AzimuthalIntegrator):
         self._wavelength_max = 100.e-10
 
     def guess_poni(self):
-        """
-        Poni can be guessed by the centroid of the ring with lowest 2Theta
+        """PONI can be guessed by the centroid of the ring with lowest 2Theta
+
+        It may try to fit an ellipse and sometimes it works
         """
 
         if len(self.calibrant.dSpacing):
@@ -146,14 +158,49 @@ class GeometryRefinement(AzimuthalIntegrator):
         asrt = tth.argsort()
         tth = tth[asrt]
         srtdata = self.data[asrt]
-        smallRing = srtdata[tth < (tth.min() + 1e-6)]
+        tth_min = tth.min()
+        smallRing = srtdata[tth < (tth_min + 1e-6)]
         smallRing1 = smallRing[:, 0]
         smallRing2 = smallRing[:, 1]
         smallRing_in_m = self.detector.calc_cartesian_positions(smallRing1,
                                                                 smallRing2)
-        l = len(smallRing)
-        self.poni1 = smallRing_in_m[0].sum() / l
-        self.poni2 = smallRing_in_m[1].sum() / l
+        nbpt = len(smallRing)
+        worked = False
+        if nbpt > 5:
+            # If there are many control point on the inner-most ring, fit an ellipse
+            try:
+                ellipse = fit_ellipse(*smallRing_in_m[:2])
+                direct_dist = ellipse.half_long_axis / numpy.tan(tth_min)
+                tilt = numpy.arctan2(ellipse.half_long_axis - ellipse.half_short_axis, ellipse.half_short_axis)
+                cos_tilt = numpy.cos(tilt)
+                sin_tilt = numpy.sin(tilt)
+                angle = (ellipse.angle + numpy.pi / 2.0) % numpy.pi
+                cos_tpr = numpy.cos(angle)
+                sin_tpr = numpy.sin(angle)
+                dist = direct_dist * cos_tilt
+                poni1 = ellipse.center_1 - direct_dist * sin_tilt * sin_tpr
+                poni2 = ellipse.center_2 - direct_dist * sin_tilt * cos_tpr
+                rot2 = numpy.arcsin(sin_tilt * sin_tpr)  # or pi-
+                rot1 = numpy.arccos(min(1.0, max(-1.0, (cos_tilt / numpy.sqrt(1 - sin_tpr * sin_tpr * sin_tilt * sin_tilt)))))  # + or -
+                if cos_tpr * sin_tilt > 0:
+                    rot1 = -rot1
+                rot3 = 0
+            except:
+                worked = False
+            else:
+                if numpy.isnan(dist + poni1 + poni2 + rot1 + rot2 + rot3):
+                    worked = False
+                else:
+                    worked = True
+                    self.dist = dist
+                    self.poni1 = poni1
+                    self.poni2 = poni2
+                    self.rot1 = rot1
+                    self.rot2 = rot2
+                    self.rot3 = rot3
+        if not worked:
+            self.poni1 = smallRing_in_m[0].sum() / nbpt
+            self.poni2 = smallRing_in_m[1].sum() / nbpt
 
     def set_tolerance(self, value=10):
         """
@@ -242,22 +289,20 @@ class GeometryRefinement(AzimuthalIntegrator):
         self.param = numpy.array([self._dist, self._poni1, self._poni2,
                                   self._rot1, self._rot2, self._rot3],
                                  dtype=numpy.float64)
-        newParam, rc = leastsq(self.residu1, self.param,
-                               args=(self.data[:, 0],
-                                     self.data[:, 1],
-                                     self.data[:, 2]))
+        new_param, rc = leastsq(self.residu1, self.param,
+                                args=(self.data[:, 0],
+                                      self.data[:, 1],
+                                      self.data[:, 2]))
         oldDeltaSq = self.chi2(tuple(self.param))
-        newDeltaSq = self.chi2(tuple(newParam))
+        newDeltaSq = self.chi2(tuple(new_param))
         logger.info("Least square retcode=%s %s --> %s",
                     rc, oldDeltaSq, newDeltaSq)
         if newDeltaSq < oldDeltaSq:
-            i = abs(self.param - newParam).argmax()
+            i = abs(self.param - new_param).argmax()
             d = ["dist", "poni1", "poni2", "rot1", "rot2", "rot3"]
             logger.info("maxdelta on %s: %s --> %s ",
-                        d[i], self.param[i], newParam[i])
-            self.param = newParam
-            self.dist, self.poni1, self.poni2, \
-                self.rot1, self.rot2, self.rot3 = tuple(newParam)
+                        d[i], self.param[i], new_param[i])
+            self.set_param(new_param)
             return newDeltaSq
         else:
             return oldDeltaSq
@@ -281,34 +326,32 @@ class GeometryRefinement(AzimuthalIntegrator):
             pos1 = self.data[:, 1]
             ring = self.data[:, 2].astype(numpy.int32)
             weight = None
-            newParam = fmin_slsqp(self.residu2, self.param, iter=maxiter,
-                              args=(pos0, pos1, ring),
-                              bounds=bounds,
-                              acc=1.0e-12,
-                              iprint=(logger.getEffectiveLevel() <= logging.INFO))
+            new_param = fmin_slsqp(self.residu2, self.param, iter=maxiter,
+                                   args=(pos0, pos1, ring),
+                                   bounds=bounds,
+                                   acc=1.0e-12,
+                                   iprint=(logger.getEffectiveLevel() <= logging.INFO))
 
         elif self.data.shape[-1] == 4:
             pos0 = self.data[:, 0]
             pos1 = self.data[:, 1]
             ring = self.data[:, 2].astype(numpy.int32)
             weight = self.data[:, 3]
-            newParam = fmin_slsqp(self.residu2_weighted, self.param, iter=maxiter,
-                              args=(pos0, pos1, ring, weight),
-                              bounds=bounds,
-                              acc=1.0e-12,
-                              iprint=(logger.getEffectiveLevel() <= logging.INFO))
+            new_param = fmin_slsqp(self.residu2_weighted, self.param, iter=maxiter,
+                                   args=(pos0, pos1, ring, weight),
+                                   bounds=bounds,
+                                   acc=1.0e-12,
+                                   iprint=(logger.getEffectiveLevel() <= logging.INFO))
         oldDeltaSq = self.chi2() / self.data.shape[0]
-        newDeltaSq = self.chi2(newParam) / self.data.shape[0]
+        newDeltaSq = self.chi2(new_param) / self.data.shape[0]
         logger.info("Constrained Least square %s --> %s",
                     oldDeltaSq, newDeltaSq)
         if newDeltaSq < oldDeltaSq:
-            i = abs(self.param - newParam).argmax()
+            i = abs(self.param - new_param).argmax()
 
             logger.info("maxdelta on %s: %s --> %s ",
-                        d[i], self.param[i], newParam[i])
-            self.param = newParam
-            self.dist, self.poni1, self.poni2, \
-                self.rot1, self.rot2, self.rot3 = tuple(newParam)
+                        d[i], self.param[i], new_param[i])
+            self.set_param(new_param)
             return newDeltaSq
         else:
             return oldDeltaSq
@@ -339,35 +382,35 @@ class GeometryRefinement(AzimuthalIntegrator):
             pos1 = self.data[:, 1]
             ring = self.data[:, 2].astype(numpy.int32)
             weight = None
-            newParam = fmin_slsqp(self.residu2_wavelength,
-                                 self.param, iter=maxiter,
-                                 args=(pos0, pos1, ring),
-                                 bounds=bounds,
-                                 acc=1.0e-12,
-                                 iprint=(logger.getEffectiveLevel() <= logging.INFO))
+            new_param = fmin_slsqp(self.residu2_wavelength,
+                                   self.param, iter=maxiter,
+                                   args=(pos0, pos1, ring),
+                                   bounds=bounds,
+                                   acc=1.0e-12,
+                                   iprint=(logger.getEffectiveLevel() <= logging.INFO))
 
         elif self.data.shape[-1] == 4:
             pos0 = self.data[:, 0]
             pos1 = self.data[:, 1]
             ring = self.data[:, 2].astype(numpy.int32)
             weight = self.data[:, 3]
-            newParam = fmin_slsqp(self.residu2_wavelength_weighted,
-                                 self.param, iter=maxiter,
-                                 args=(pos0, pos1, ring, weight),
-                                 bounds=bounds,
-                                 acc=1.0e-12,
-                                 iprint=(logger.getEffectiveLevel() <= logging.INFO))
+            new_param = fmin_slsqp(self.residu2_wavelength_weighted,
+                                   self.param, iter=maxiter,
+                                   args=(pos0, pos1, ring, weight),
+                                   bounds=bounds,
+                                   acc=1.0e-12,
+                                   iprint=(logger.getEffectiveLevel() <= logging.INFO))
         oldDeltaSq = self.chi2_wavelength() / self.data.shape[0]
-        newDeltaSq = self.chi2_wavelength(newParam) / self.data.shape[0]
+        newDeltaSq = self.chi2_wavelength(new_param) / self.data.shape[0]
         logger.info("Constrained Least square %s --> %s",
                     oldDeltaSq, newDeltaSq)
         if newDeltaSq < oldDeltaSq:
-            i = abs(self.param - newParam).argmax()
+            i = abs(self.param - new_param).argmax()
             logger.info("maxdelta on %s: %s --> %s ",
-                        d[i], self.param[i], newParam[i])
-            self.param = newParam
-            self.dist, self.poni1, self.poni2, self.rot1, self.rot2, self.rot3 = tuple(newParam[:-1])
-            self.wavelength = 1e-10 * newParam[-1]
+                        d[i], self.param[i], new_param[i])
+
+            self.set_param(new_param[:-1])
+            self.wavelength = 1e-10 * new_param[-1]
             return newDeltaSq
         else:
             return oldDeltaSq
@@ -376,23 +419,21 @@ class GeometryRefinement(AzimuthalIntegrator):
         self.param = numpy.array([self.dist, self.poni1, self.poni2,
                                   self.rot1, self.rot2, self.rot3],
                                  dtype=numpy.float64)
-        newParam = fmin(self.residu2, self.param,
-                        args=(self.data[:, 0],
-                              self.data[:, 1],
-                              self.data[:, 2]),
-                        maxiter=maxiter,
-                        xtol=1.0e-12)
+        new_param = fmin(self.residu2, self.param,
+                         args=(self.data[:, 0],
+                               self.data[:, 1],
+                               self.data[:, 2]),
+                         maxiter=maxiter,
+                         xtol=1.0e-12)
         oldDeltaSq = self.chi2(tuple(self.param)) / self.data.shape[0]
-        newDeltaSq = self.chi2(tuple(newParam)) / self.data.shape[0]
+        newDeltaSq = self.chi2(tuple(new_param)) / self.data.shape[0]
         logger.info("Simplex %s --> %s", oldDeltaSq, newDeltaSq)
         if newDeltaSq < oldDeltaSq:
-            i = abs(self.param - newParam).argmax()
+            i = abs(self.param - new_param).argmax()
             d = ["dist", "poni1", "poni2", "rot1", "rot2", "rot3"]
             logger.info("maxdelta on %s : %s --> %s ",
-                        d[i], self.param[i], newParam[i])
-            self.param = newParam
-            self.dist, self.poni1, self.poni2, \
-                self.rot1, self.rot2, self.rot3 = tuple(newParam)
+                        d[i], self.param[i], new_param[i])
+            self.set_param(new_param)
             return newDeltaSq
         else:
             return oldDeltaSq
@@ -417,18 +458,16 @@ class GeometryRefinement(AzimuthalIntegrator):
                                self._rot2_max,
                                self._rot3_max],
                         maxiter=maxiter)
-        newParam = result[0]
+        new_param = result[0]
         oldDeltaSq = self.chi2() / self.data.shape[0]
-        newDeltaSq = self.chi2(newParam) / self.data.shape[0]
+        newDeltaSq = self.chi2(new_param) / self.data.shape[0]
         logger.info("Anneal  %s --> %s", oldDeltaSq, newDeltaSq)
         if newDeltaSq < oldDeltaSq:
-            i = abs(self.param - newParam).argmax()
+            i = abs(self.param - new_param).argmax()
             d = ["dist", "poni1", "poni2", "rot1", "rot2", "rot3"]
             logger.info("maxdelta on %s : %s --> %s ",
-                        d[i], self.param[i], newParam[i])
-            self.param = newParam
-            self.dist, self.poni1, self.poni2, \
-                self.rot1, self.rot2, self.rot3 = tuple(newParam)
+                        d[i], self.param[i], new_param[i])
+            self.set_param(new_param)
             return newDeltaSq
         else:
             return oldDeltaSq
@@ -445,7 +484,9 @@ class GeometryRefinement(AzimuthalIntegrator):
             if len(param) == 6:
                 param.append(1e10 * self.wavelength)
         return self.residu2_wavelength(param,
-                            self.data[:, 0], self.data[:, 1], self.data[:, 2])
+                                       self.data[:, 0],
+                                       self.data[:, 1],
+                                       self.data[:, 2])
 
     def curve_fit(self, with_rot=True):
         """Refine the geometry and provide confidence interval
@@ -480,9 +521,7 @@ class GeometryRefinement(AzimuthalIntegrator):
         err = numpy.sqrt(numpy.diag(pcov))
         print("err: %s" % err)
         if obt < ref:
-            self.param = popt
-            self.dist, self.poni1, self.poni2, \
-                    self.rot1, self.rot2, self.rot3 = tuple(popt)
+            self.set_param(popt)
         error = {}
         confidence = {}
         for k, v in zip(("dist", "poni1", "poni2", "rot1", "rot2", "rot3"), err):
@@ -582,28 +621,28 @@ class GeometryRefinement(AzimuthalIntegrator):
              str(self.poni1 / self.pixel1), str(self.poni2 / self.pixel2),
              str(self.dist), str(self.rot1), str(self.rot2), str(self.rot3)],
             stdout=subprocess.PIPE)
-        newParam = [self.dist, self.poni1, self.poni2,
-                    self.rot1, self.rot2, self.rot3]
+        new_param = [self.dist, self.poni1, self.poni2,
+                     self.rot1, self.rot2, self.rot3]
         for line in roca.stdout:
             word = line.split()
             if len(word) == 3:
                 if word[0] == "cen1":
-                    newParam[1] = float(word[1]) * self.pixel1
+                    new_param[1] = float(word[1]) * self.pixel1
                 if word[0] == "cen2":
-                    newParam[2] = float(word[1]) * self.pixel2
+                    new_param[2] = float(word[1]) * self.pixel2
                 if word[0] == "dis":
-                    newParam[0] = float(word[1])
+                    new_param[0] = float(word[1])
                 if word[0] == "rot1":
-                    newParam[3] = float(word[1])
+                    new_param[3] = float(word[1])
                 if word[0] == "rot2":
-                    newParam[4] = float(word[1])
+                    new_param[4] = float(word[1])
                 if word[0] == "rot3":
-                    newParam[5] = float(word[1])
-        print("Roca %s --> %s" % (self.chi2() / self.data.shape[0], self.chi2(newParam) / self.data.shape[0]))
-        if self.chi2(tuple(newParam)) < self.chi2(tuple(self.param)):
-            self.param = newParam
+                    new_param[5] = float(word[1])
+        print("Roca %s --> %s" % (self.chi2() / self.data.shape[0], self.chi2(new_param) / self.data.shape[0]))
+        if self.chi2(tuple(new_param)) < self.chi2(tuple(self.param)):
+            self.param = new_param
             self.dist, self.poni1, self.poni2, \
-                self.rot1, self.rot2, self.rot3 = tuple(newParam)
+                self.rot1, self.rot2, self.rot3 = tuple(new_param)
 
         tmpf.close()
 
