@@ -37,7 +37,7 @@ __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "28/11/2016"
+__date__ = "31/08/2017"
 __status__ = "development"
 
 import logging
@@ -297,7 +297,7 @@ class AIWidget(qt.QWidget):
                     w.correct_solid_angle = self.__get_correct_solid_angle()
                     w.error_model = self.__get_error_model()
                     w.method = self.get_method()
-                    w.is_safe = False
+                    w.safe = False
                     if self.do_2D.isChecked():
                         w.nbpt_azim = self.__get_nbpt_azim()
                     else:
@@ -358,6 +358,7 @@ class AIWidget(qt.QWidget):
                         fab_img = fabio.open(item)
                         multiframe = (fab_img.nframes > 1)
                         kwarg["data"] = fab_img.data
+                        kwarg["metadata"] = fab_img.header
                         if self.hdf5_path is None:
                             if self.output_path and op.isdir(self.output_path):
                                 outpath = op.join(self.output_path, op.splitext(op.basename(item))[0])
@@ -379,7 +380,9 @@ class AIWidget(qt.QWidget):
                         writer = HDF5Writer(outpath + "_pyFAI.h5")
                         writer.init(config)
                         for i in range(fab_img.nframes):
-                            kwarg["data"] = fab_img.getframe(i).data
+                            frame = fab_img.getframe(i)
+                            kwarg["data"] = frame.data
+                            kwarg["metadata"] = frame.header
                             if "npt_azim" in kwarg:
                                 res = ai.integrate2d(**kwarg)
                             else:
@@ -554,13 +557,34 @@ class AIWidget(qt.QWidget):
         if setup_data.get("do_OpenCL"):
             self.openCL_changed()
 
+    def getOpenFileName(self, title):
+        """Display a dialog to select a filename and return it.
+
+        Returns None if nothing selected.
+
+        This code is compatible PyQt4/PyQt5 which is not the case for static
+        functions provided by `qt.QFileDialog`.
+        """
+        dialog = qt.QFileDialog(self)
+        dialog.setWindowTitle(title)
+        dialog.setModal(True)
+        dialog.setFileMode(qt.QFileDialog.ExistingFile)
+
+        result = dialog.exec_()
+        if not result:
+            return None
+
+        filename = dialog.selectedFiles()[0]
+        return filename
+
     def select_ponifile(self):
-        ponifile = qt.QFileDialog.getOpenFileName()
-        self.set_ponifile(str_(ponifile))
+        ponifile = self.getOpenFileName("Open a poni file")
+        if ponifile is not None:
+            self.set_ponifile(ponifile)
 
     def select_splinefile(self):
         logger.debug("select_splinefile")
-        splinefile = str_(qt.QFileDialog.getOpenFileName())
+        splinefile = self.getOpenFileName("Open a spline file")
         if splinefile:
             try:
                 ai = AzimuthalIntegrator()
@@ -573,21 +597,21 @@ class AIWidget(qt.QWidget):
 
     def select_maskfile(self):
         logger.debug("select_maskfile")
-        maskfile = str_(qt.QFileDialog.getOpenFileName())
+        maskfile = self.getOpenFileName("Open a mask image")
         if maskfile:
             self.mask_file.setText(maskfile or "")
             self.do_mask.setChecked(True)
 
     def select_darkcurrent(self):
         logger.debug("select_darkcurrent")
-        darkcurrent = str_(qt.QFileDialog.getOpenFileName())
+        darkcurrent = self.getOpenFileName("Open a dark image")
         if darkcurrent:
             self.dark_current.setText(str_(darkcurrent))
             self.do_dark.setChecked(True)
 
     def select_flatfield(self):
         logger.debug("select_flatfield")
-        flatfield = str_(qt.QFileDialog.getOpenFileName())
+        flatfield = self.getOpenFileName("Open a flatfield image")
         if flatfield:
             self.flat_field.setText(str_(flatfield))
             self.do_flat.setChecked(True)
@@ -698,8 +722,15 @@ class AIWidget(qt.QWidget):
 
     def save_config(self):
         logger.debug("save_config")
-        json_file = str_(qt.QFileDialog.getSaveFileName(caption="Save configuration as json",
-                                                           directory=self.json_file,
-                                                           filter="Config (*.json)"))
+
+        result = qt.QFileDialog.getSaveFileName(
+            caption="Save configuration as json",
+            directory=self.json_file,
+            filter="Config (*.json)")
+        if isinstance(result, tuple):
+            # PyQt5 compatibility
+            result = result[0]
+
+        json_file = result
         if json_file:
             self.dump(json_file)
