@@ -26,15 +26,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+"""test suite for Azimuthal integrator class"""
+
 from __future__ import absolute_import, division, print_function
 
-__doc__ = "test suite for Azimuthal integrator class"
 __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "28/11/2016"
-
+__date__ = "06/09/2017"
 
 import unittest
 import os
@@ -44,6 +44,7 @@ import time
 import copy
 import fabio
 import tempfile
+import gc
 from .utilstest import UtilsTest, Rwp, getLogger, recursive_delete
 logger = getLogger(__file__)
 from ..azimuthalIntegrator import AzimuthalIntegrator
@@ -57,70 +58,98 @@ except (ImportError, Exception):
     import six
 
 
+@unittest.skipIf(UtilsTest.low_mem, "test using >500M")
 class TestAzimPilatus(unittest.TestCase):
+    """This test uses a lot of memory"""
     @classmethod
     def setUpClass(cls):
         cls.img = UtilsTest.getimage("Pilatus6M.cbf")
 
+    @classmethod
+    def tearDownClass(cls):
+        super(TestAzimPilatus, cls).tearDownClass()
+        cls.img = None
+
     def setUp(self):
         """Download files"""
         self.data = fabio.open(self.img).data
         self.ai = AzimuthalIntegrator(detector="pilatus6m")
         self.ai.setFit2D(300, 1326, 1303)
 
+    def tearDown(self):
+        unittest.TestCase.tearDown(self)
+        self.data = self.ai = None
+
     def test_separate(self):
         bragg, amorphous = self.ai.separate(self.data)
         self.assertTrue(amorphous.max() < bragg.max(), "bragg is more intense than amorphous")
         self.assertTrue(amorphous.std() < bragg.std(), "bragg is more variatic than amorphous")
+        self.ai.reset()
 
 
 class TestAzimHalfFrelon(unittest.TestCase):
     """basic test"""
 
-    def setUp(self):
+    @classmethod
+    def setUpClass(cls):
         """Download files"""
+        super(TestAzimHalfFrelon, cls).setUpClass()
 
         fit2dFile = 'fit2d.dat'
         halfFrelon = "LaB6_0020.edf"
         splineFile = "halfccd.spline"
         poniFile = "LaB6.poni"
 
-        self.tmpfiles = {"cython": os.path.join(tmp_dir, "cython.dat"),
+        cls.tmpfiles = {"cython": os.path.join(tmp_dir, "cython.dat"),
                          "cythonSP": os.path.join(tmp_dir, "cythonSP.dat"),
                          "numpy": os.path.join(tmp_dir, "numpy.dat")}
 
-        self.fit2dFile = UtilsTest.getimage(fit2dFile)
-        self.halfFrelon = UtilsTest.getimage(halfFrelon)
-        self.splineFile = UtilsTest.getimage(splineFile)
+        cls.fit2dFile = UtilsTest.getimage(fit2dFile)
+        cls.halfFrelon = UtilsTest.getimage(halfFrelon)
+        cls.splineFile = UtilsTest.getimage(splineFile)
         poniFile = UtilsTest.getimage(poniFile)
 
         with open(poniFile) as f:
             data = []
             for line in f:
                 if line.startswith("SplineFile:"):
-                    data.append("SplineFile: " + self.splineFile)
+                    data.append("SplineFile: " + cls.splineFile)
                 else:
                     data.append(line.strip())
-        self.poniFile = os.path.join(tmp_dir, os.path.basename(poniFile))
+        cls.poniFile = os.path.join(tmp_dir, os.path.basename(poniFile))
         if not os.path.isdir(tmp_dir):
             os.makedirs(tmp_dir)
 
-        with open(self.poniFile, "w") as f:
+        with open(cls.poniFile, "w") as f:
             f.write(os.linesep.join(data))
-        self.fit2d = numpy.loadtxt(self.fit2dFile)
-        self.ai = AzimuthalIntegrator()
-        self.ai.load(self.poniFile)
-        self.data = fabio.open(self.halfFrelon).data
-        for tmpfile in self.tmpfiles.values():
+        cls.fit2d = numpy.loadtxt(cls.fit2dFile)
+        cls.ai = AzimuthalIntegrator()
+        cls.ai.load(cls.poniFile)
+        cls.data = fabio.open(cls.halfFrelon).data
+        for tmpfile in cls.tmpfiles.values():
             if os.path.isfile(tmpfile):
                 os.unlink(tmpfile)
 
-    def tearDown(self):
+    @classmethod
+    def tearDownClass(cls):
         """Remove temporary files"""
-        for fn in self.tmpfiles.values():
+        super(TestAzimHalfFrelon, cls).tearDownClass()
+        for fn in cls.tmpfiles.values():
             if os.path.exists(fn):
                 os.unlink(fn)
+        cls.fit2d = None
+        cls.ai = None
+        cls.data = None
+        cls.tmpfiles = None
 
+    def tearDown(self):
+        unittest.TestCase.tearDown(self)
+        try:
+            self.__class__.ai.reset()
+        except Exception as e:
+            logger.error(e)
+
+    @unittest.skipIf(UtilsTest.low_mem, "test using >100Mb")
     def test_numpy_vs_fit2d(self):
         """
         Compare numpy histogram with results of fit2d
@@ -141,8 +170,9 @@ class TestAzimHalfFrelon(unittest.TestCase):
             fig.legend(handles, labels)
             fig.show()
             six.moves.input("Press enter to quit")
-        assert rwp < 11
+        self.assertLess(rwp, 11, "Rwp numpy/fit2d: %.3f" % rwp)
 
+    @unittest.skipIf(UtilsTest.low_mem, "test using >100Mb")
     def test_cython_vs_fit2d(self):
         """
         Compare cython histogram with results of fit2d
@@ -165,14 +195,16 @@ class TestAzimHalfFrelon(unittest.TestCase):
             fig.legend(handles, labels)
             fig.show()
             six.moves.input("Press enter to quit")
-        assert rwp < 11
+        self.assertLess(rwp, 11, "Rwp cython/fit2d: %.3f" % rwp)
 
+    @unittest.skipIf(UtilsTest.low_mem, "test using >200M")
     def test_cythonSP_vs_fit2d(self):
         """
         Compare cython splitPixel with results of fit2d
         """
         logger.info(self.ai.__repr__())
-        pos = self.ai.cornerArray(self.data.shape)
+        self.ai.cornerArray(self.data.shape)
+        # this was just to enforce the initalization of the array
         t0 = time.time()
         logger.info("in test_cythonSP_vs_fit2d Before SP")
 
@@ -197,22 +229,21 @@ class TestAzimHalfFrelon(unittest.TestCase):
             fig.legend(handles, labels)
             fig.show()
             six.moves.input("Press enter to quit")
-        assert rwp < 11
+        self.assertLess(rwp, 11, "Rwp cythonSP/fit2d: %.3f" % rwp)
 
+    @unittest.skipIf(UtilsTest.low_mem, "test using >100Mb")
     def test_cython_vs_numpy(self):
         """
         Compare cython histogram with numpy histogram
         """
-#        logger.info(self.ai.__repr__())
-        data = self.data
-        tth_np, I_np = self.ai.xrpd_numpy(data,
+        tth_np, I_np = self.ai.xrpd_numpy(self.__class__.data,
                                           len(self.fit2d),
                                           correctSolidAngle=False)
-        tth_cy, I_cy = self.ai.xrpd_cython(data,
+        tth_cy, I_cy = self.ai.xrpd_cython(self.__class__.data,
                                            len(self.fit2d),
                                            correctSolidAngle=False)
         logger.info("before xrpd_splitPixel")
-        tth_sp, I_sp = self.ai.xrpd_splitPixel(data,
+        tth_sp, I_sp = self.ai.xrpd_splitPixel(self.__class__.data,
                                                len(self.fit2d),
                                                correctSolidAngle=False)
         logger.info("After xrpd_splitPixel")
@@ -232,7 +263,7 @@ class TestAzimHalfFrelon(unittest.TestCase):
             fig.show()
             six.moves.input("Press enter to quit")
 
-        assert rwp < 3
+        self.assertLess(rwp, 3, "Rwp cython/numpy: %.3f" % rwp)
 
     def test_separate(self):
         "test separate with a mask. issue #209 regression test"
@@ -241,17 +272,48 @@ class TestAzimHalfFrelon(unittest.TestCase):
         self.assertTrue(amorphous.max() < bragg.max(), "bragg is more intense than amorphous")
         self.assertTrue(amorphous.std() < bragg.std(), "bragg is more variatic than amorphous")
 
+    @unittest.skipIf(UtilsTest.opencl is False, "User request to skip OpenCL tests")
+    @unittest.skipIf(UtilsTest.low_mem, "test using >100Mb")
+    def test_medfilt1d(self):
+        ref = self.ai.medfilt1d(self.data, 1000, unit="2th_deg", method="csr")
+        ocl = self.ai.medfilt1d(self.data, 1000, unit="2th_deg", method="ocl_csr")
+        rwp = Rwp(ref, ocl)
+        logger.info("test_medfilt1d median Rwp = %.3f", rwp)
+        self.assertLess(rwp, 1, "Rwp medfilt1d Numpy/OpenCL: %.3f" % rwp)
+
+        ref = self.ai.medfilt1d(self.data, 1000, unit="2th_deg", method="csr", percentile=(20, 80))
+        ocl = self.ai.medfilt1d(self.data, 1000, unit="2th_deg", method="ocl_csr", percentile=(20, 80))
+        rwp = Rwp(ref, ocl)
+        logger.info("test_medfilt1d trimmed-mean Rwp = %.3f", rwp)
+        self.assertLess(rwp, 3, "Rwp trimmed-mean Numpy/OpenCL: %.3f" % rwp)
+        ref = ocl = rwp = None
+        gc.collect()
+
+    def test_radial(self):
+
+        res = self.ai.integrate_radial(self.data, npt=360, npt_rad=10,
+                                       radial_range=(3.6, 3.9), radial_unit="2th_deg")
+        self.assertLess(res[0].min(), -179, "chi min at -180")
+        self.assertGreater(res[0].max(), 179, "chi max at +180")
+        self.assertGreater(res[1].min(), 120, "intensity min in ok")
+        self.assertLess(res[1].max(), 10000, "intensity max in ok")
+
+        res = self.ai.integrate_radial(self.data, npt=360, npt_rad=10,
+                                       radial_range=(3.6, 3.9), radial_unit="2th_deg", unit="chi_rad")
+        self.assertLess(res[0].min(), -3, "chi min at -3rad")
+        self.assertGreater(res[0].max(), 0, "chi max at +3rad")
+
 
 class TestFlatimage(unittest.TestCase):
     """test the caking of a flat image"""
     epsilon = 1e-4
 
     def test_splitPixel(self):
-        shape = (2000, 2001)
+        shape = (200, 201)
         data = numpy.ones(shape, dtype="float64")
-        det = Detector(1e-5, 1e-5, max_shape=(2000, 2001))
+        det = Detector(1e-4, 1e-4, max_shape=shape)
         ai = AzimuthalIntegrator(0.1, 1e-2, 1e-2, detector=det)
-        I = ai.xrpd2_splitPixel(data, 2048, 2048, correctSolidAngle=False, dummy=-1.0)[0]
+        I = ai.xrpd2_splitPixel(data, 256, 2256, correctSolidAngle=False, dummy=-1.0)[0]
 #        I = ai.xrpd2(data, 2048, 2048, correctSolidAngle=False, dummy= -1.0)
 
         if logger.getEffectiveLevel() == logging.DEBUG:
@@ -267,10 +329,11 @@ class TestFlatimage(unittest.TestCase):
         assert abs(I.max() - 1.0) < self.epsilon
 
     def test_splitBBox(self):
-        data = numpy.ones((2000, 2000), dtype="float64")
-        ai = AzimuthalIntegrator(0.1, 1e-2, 1e-2, pixel1=1e-5, pixel2=1e-5)
-        I = ai.xrpd2_splitBBox(data, 2048, 2048, correctSolidAngle=False, dummy=-1.0)[0]
-#        I = ai.xrpd2(data, 2048, 2048, correctSolidAngle=False, dummy= -1.0)
+        shape = (200, 201)
+        data = numpy.ones(shape, dtype="float64")
+        det = Detector(1e-4, 1e-4, max_shape=shape)
+        ai = AzimuthalIntegrator(0.1, 1e-2, 1e-2, detector=det)
+        I = ai.xrpd2_splitBBox(data, 256, 256, correctSolidAngle=False, dummy=-1.0)[0]
 
         if logger.getEffectiveLevel() == logging.DEBUG:
             logging.info("Plotting results")
@@ -312,14 +375,19 @@ class TestSaxs(unittest.TestCase):
 #         self.assertTrue(abs(self.ai.create_mask(data, mask=mask, dummy=-48912, delta_dummy=40000).astype(int) - fabio.open(self.maskDummy).data).max() == 0, "test_dummy")
 
     def test_normalization_factor(self):
+
         ai = AzimuthalIntegrator(detector="Pilatus100k")
         ai.wavelength = 1e-10
-        methods = ["cython", "numpy", "lut", "csr", "ocl_lut", "ocl_csr", "splitpixel"]
+        methods = ["cython", "numpy", "lut", "csr", "splitpixel"]
+        if UtilsTest.opencl:
+            methods.extend(["ocl_lut", "ocl_csr"])
+
         ref1d = {}
         ref2d = {}
 
         data = fabio.open(self.edfPilatus).data[:ai.detector.shape[0], :ai.detector.shape[1]]
         for method in methods:
+            logger.debug("TestSaxs.test_normalization_factor method= " + method)
             ref1d[method + "_1"] = ai.integrate1d(copy.deepcopy(data), 100, method=method, error_model="poisson")
             ref1d[method + "_10"] = ai.integrate1d(copy.deepcopy(data), 100, method=method, normalization_factor=10, error_model="poisson")
             ratio_i = ref1d[method + "_1"].intensity.mean() / ref1d[method + "_10"].intensity.mean()
@@ -327,14 +395,27 @@ class TestSaxs(unittest.TestCase):
 
             self.assertAlmostEqual(ratio_i, 10.0, places=3, msg="test_normalization_factor 1d intensity Method: %s ratio: %s expected 10" % (method, ratio_i))
             self.assertAlmostEqual(ratio_s, 10.0, places=3, msg="test_normalization_factor 1d sigma Method: %s ratio: %s expected 10" % (method, ratio_s))
-            #ai.reset()
+            # ai.reset()
             ref2d[method + "_1"] = ai.integrate2d(copy.deepcopy(data), 100, 36, method=method, error_model="poisson")
             ref2d[method + "_10"] = ai.integrate2d(copy.deepcopy(data), 100, 36, method=method, normalization_factor=10, error_model="poisson")
             ratio_i = ref2d[method + "_1"].intensity.mean() / ref2d[method + "_10"].intensity.mean()
-#             ratio_s = ref2d[method + "_1"].sigma.mean() / ref2d[method + "_10"].sigma.mean()
+            # ratio_s = ref2d[method + "_1"].sigma.mean() / ref2d[method + "_10"].sigma.mean()
             self.assertAlmostEqual(ratio_i, 10.0, places=3, msg="test_normalization_factor 2d intensity Method: %s ratio: %s expected 10" % (method, ratio_i))
-#             self.assertAlmostEqual(ratio_s, 10.0, places=3, msg="test_normalization_factor 2d sigma Method: %s ratio: %s expected 10" % (method, ratio_s))
-            #ai.reset()
+            # self.assertAlmostEqual(ratio_s, 10.0, places=3, msg="test_normalization_factor 2d sigma Method: %s ratio: %s expected 10" % (method, ratio_s))
+            # ai.reset()
+
+    def test_inpainting(self):
+        logger.debug("TestSaxs.test_inpainting")
+        img = fabio.open(self.edfPilatus).data
+        ai = AzimuthalIntegrator(detector="Pilatus1M")
+        ai.setFit2D(2000, 870, 102.123456789)  # rational numbers are hell !
+        mask = img < 0
+        inp = ai.inpainting(img, mask)
+        neg = (inp < 0).sum()
+        logger.debug("neg=%s" % neg)
+        self.assertTrue(neg == 0, "all negative pixels got inpainted actually all but %s" % neg)
+        self.assertTrue(mask.sum() > 0, "some pixel needed inpainting")
+
 
 class TestSetter(unittest.TestCase):
     def setUp(self):
@@ -367,21 +448,17 @@ class TestSetter(unittest.TestCase):
 
 
 def suite():
+    loader = unittest.defaultTestLoader.loadTestsFromTestCase
     testsuite = unittest.TestSuite()
-    testsuite.addTest(TestAzimHalfFrelon("test_cython_vs_fit2d"))
-    testsuite.addTest(TestAzimHalfFrelon("test_numpy_vs_fit2d"))
-    testsuite.addTest(TestAzimHalfFrelon("test_cythonSP_vs_fit2d"))
-    testsuite.addTest(TestAzimHalfFrelon("test_cython_vs_numpy"))
-    testsuite.addTest(TestAzimHalfFrelon("test_separate"))
-    testsuite.addTest(TestFlatimage("test_splitPixel"))
-    testsuite.addTest(TestFlatimage("test_splitBBox"))
-    testsuite.addTest(TestSetter("test_flat"))
-    testsuite.addTest(TestSetter("test_dark"))
-    testsuite.addTest(TestAzimPilatus("test_separate"))
-    testsuite.addTest(TestSaxs("test_mask"))
-    testsuite.addTest(TestSaxs("test_normalization_factor"))
+    testsuite.addTest(loader(TestAzimHalfFrelon))
+    testsuite.addTest(loader(TestFlatimage))
+    testsuite.addTest(loader(TestSetter))
+    # Consumes a lot of memory
+    # testsuite.addTest(loader(TestAzimPilatus))
+    testsuite.addTest(loader(TestSaxs))
     return testsuite
 
+
 if __name__ == '__main__':
     runner = unittest.TextTestRunner()
     runner.run(suite())
