@@ -33,7 +33,7 @@ __author__ = "Jérôme Kieffer"
 __contact__ = "Jérôme.Kieffer@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "28/11/2016"
+__date__ = "19/07/2017"
 
 import unittest
 import numpy
@@ -85,13 +85,12 @@ class TestConvolution(unittest.TestCase):
 
 
 def suite():
+    loader = unittest.defaultTestLoader.loadTestsFromTestCase
     testsuite = unittest.TestSuite()
-    testsuite.addTest(TestConvolution("test_horizontal_convolution"))
-    testsuite.addTest(TestConvolution("test_vertical_convolution"))
-    testsuite.addTest(TestConvolution("test_gaussian"))
-    testsuite.addTest(TestConvolution("test_gaussian_filter"))
+    testsuite.addTest(loader(TestConvolution))
     return testsuite
 
+
 if __name__ == '__main__':
     runner = unittest.TextTestRunner()
     runner.run(suite())
