@@ -26,23 +26,23 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from __future__ import absolute_import, division, print_function
-
-__doc__ = """tests for Jon's geometry changes
+"""tests for Jon's geometry changes
 FIXME : make some tests that the functions do what is expected
 """
 
+from __future__ import absolute_import, division, print_function
+
 
 import unittest
 import numpy
-from .utilstest import UtilsTest, getLogger, diff_img
+from .utilstest import UtilsTest, getLogger
 logger = getLogger(__file__)
 from .. import opencl
 from ..ext import splitBBox
 from ..ext import splitBBoxCSR
 from ..azimuthalIntegrator import AzimuthalIntegrator
 if opencl.ocl:
-    from .. import ocl_azim_csr
+    from ..opencl import azim_csr as ocl_azim_csr
 
 import fabio
 
@@ -60,6 +60,12 @@ class ParameterisedTestCase(unittest.TestCase):
         cls.data = fabio.open(UtilsTest.getimage("Pilatus1M.edf")).data
         cls.ai.xrpd_LUT(cls.data, cls.N)
 
+    @classmethod
+    def tearDownClass(cls):
+        cls.N = None
+        cls.ai = None
+        cls.data = None
+
     def __init__(self, methodName='runTest', param=None):
         super(ParameterisedTestCase, self).__init__(methodName)
         self.param = param
@@ -79,6 +85,10 @@ class ParameterisedTestCase(unittest.TestCase):
 
 class ParamOpenclCSR(ParameterisedTestCase):
 
+    def setUp(self):
+        if not UtilsTest.opencl:
+            self.skipTest("User request to skip OpenCL tests")
+
     def test_csr(self):
         workgroup_size = self.param
         out_ref = splitBBox.histoBBox1d(self.data, self.ai.ttha, self.ai._cached_array["2th_delta"], bins=self.N)
@@ -114,25 +124,38 @@ TESTCASES = [8 * 2 ** i for i in range(6)]  # [8, 16, 32, 64, 128, 256]
 
 
 class Test_CSR(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.N = 1000
+        cls.ai = AzimuthalIntegrator.sload(UtilsTest.getimage("Pilatus1M.poni"))
+        cls.data = fabio.open(UtilsTest.getimage("Pilatus1M.edf")).data
+        cls.ai.xrpd_LUT(cls.data, cls.N)
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.N = None
+        cls.ai = None
+        cls.data = None
+
     def test_2d_splitbbox(self):
-        ai.reset()
-        img, tth, chi = ai.integrate2d(data, N, unit="2th_deg", method="splitbbox_LUT")
-        img_csr, tth_csr, chi_csr = ai.integrate2d(data, N, unit="2th_deg", method="splitbbox_csr")
+        self.ai.reset()
+        img, tth, chi = self.ai.integrate2d(self.data, self.N, unit="2th_deg", method="splitbbox_LUT")
+        img_csr, tth_csr, chi_csr = self.ai.integrate2d(self.data, self.N, unit="2th_deg", method="splitbbox_csr")
         self.assertTrue(numpy.allclose(tth, tth_csr), " 2Th are the same")
         self.assertTrue(numpy.allclose(chi, chi_csr), " Chi are the same")
         # TODO: align on splitbbox rather then splitbbox_csr
-        diff_img(img, img_csr, "splitbbox")
+        # diff_img(img, img_csr, "splitbbox")
         self.assertTrue(numpy.allclose(img, img_csr), " img are the same")
 
     def test_2d_nosplit(self):
-        ai.reset()
-        img, tth, chi = ai.integrate2d(data, N, unit="2th_deg", method="histogram")
-        img_csr, tth_csr, chi_csr = ai.integrate2d(data, N, unit="2th_deg", method="nosplit_csr")
-#        diff_crv(tth, tth_csr, "2th")
-#        self.assertTrue(numpy.allclose(tth, tth_csr), " 2Th are the same")
-#        self.assertTrue(numpy.allclose(chi, chi_csr), " Chi are the same")
-        diff_img(img, img_csr, "no split")
-        self.assertTrue(numpy.allclose(img, img_csr), " img are the same")
+        self.ai.reset()
+        img, tth, chi = self.ai.integrate2d(self.data, self.N, unit="2th_deg", method="histogram")
+        img_csr, tth_csr, chi_csr = self.ai.integrate2d(self.data, self.N, unit="2th_deg", method="nosplit_csr")
+        # diff_crv(tth, tth_csr, "2th")
+        # self.assertTrue(numpy.allclose(tth, tth_csr), " 2Th are the same")
+        # self.assertTrue(numpy.allclose(chi, chi_csr), " Chi are the same")
+        # diff_img(img, img_csr, "no split")
+        self.assertLess(((img - img_csr) > 1).sum(), 6, " img are almost the same")
 
 
 def suite():
@@ -140,10 +163,9 @@ def suite():
     if opencl.ocl:
         for param in TESTCASES:
             testsuite.addTest(ParameterisedTestCase.parameterise(
-                    ParamOpenclCSR, param))
-    # if no opencl: no test
-    # testsuite.addTest(Test_CSR("test_2d_splitbbox"))
-    # testsuite.addTest(Test_CSR("test_2d_nosplit"))
+                              ParamOpenclCSR, param))
+    loader = unittest.defaultTestLoader.loadTestsFromTestCase
+    testsuite.addTest(loader(Test_CSR))
     return testsuite
 
 
