@@ -25,19 +25,19 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
+"test suite for masked arrays"
 
 from __future__ import absolute_import, division, print_function
 
-__doc__ = "test suite for masked arrays"
-
 __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "28/11/2016"
+__date__ = "06/09/2017"
 
 
 import tempfile
+import contextlib
 import os
 import unittest
 import numpy.testing
@@ -51,6 +51,15 @@ from ..io import DefaultAiWriter
 from ..detectors import Pilatus1M
 
 
+@contextlib.contextmanager
+def resulttempfile():
+    fd, path = tempfile.mkstemp(prefix="pyfai_", suffix=".out")
+    os.close(fd)
+    os.remove(path)
+    yield path
+    os.remove(path)
+
+
 class TestIntegrate1D(unittest.TestCase):
 
     def setUp(self):
@@ -61,14 +70,17 @@ class TestIntegrate1D(unittest.TestCase):
         self.ai = AzimuthalIntegrator(1.58323111834, 0.0334170169115, 0.0412277798782, 0.00648735642526, 0.00755810191106, 0.0, detector=Pilatus1M())
         self.ai.wavelength = 1e-10
         self.Rmax = 3
+        self.methods = ["numpy", "cython", "BBox", "splitpixel", "lut"]
+        if UtilsTest.opencl:
+            self.methods.append("lut_ocl")
 
     def tearDown(self):
         unittest.TestCase.tearDown(self)
-        self.npt = self.img = self.data = self.ai = self.Rmax
+        self.npt = self.img = self.data = self.ai = self.Rmax = None
 
     def testQ(self):
         res = {}
-        for m in ("numpy", "cython", "BBox", "splitpixel", "lut", "lut_ocl"):
+        for m in self.methods:
             res[m] = self.ai.integrate1d(self.data, self.npt, method=m, radial_range=(0.5, 5.8))
         for a in res:
             for b in res:
@@ -82,7 +94,7 @@ class TestIntegrate1D(unittest.TestCase):
 
     def testR(self):
         res = {}
-        for m in ("numpy", "cython", "BBox", "splitpixel", "lut", "lut_ocl"):
+        for m in self.methods:
             res[m] = self.ai.integrate1d(self.data, self.npt, method=m, unit="r_mm", radial_range=(20, 150))
         for a in res:
             for b in res:
@@ -96,7 +108,7 @@ class TestIntegrate1D(unittest.TestCase):
 
     def test2th(self):
         res = {}
-        for m in ("numpy", "cython", "BBox", "splitpixel", "lut", "lut_ocl"):
+        for m in self.methods:
             res[m] = self.ai.integrate1d(self.data, self.npt, method=m, unit="2th_deg", radial_range=(0.5, 5.5))
         for a in res:
             for b in res:
@@ -109,21 +121,17 @@ class TestIntegrate1D(unittest.TestCase):
                 self.assertTrue(R <= self.Rmax, mesg)
 
     def test_filename(self):
-        f = tempfile.NamedTemporaryFile(delete=True)
-        self.assertEquals(os.path.getsize(f.name), 0)
-        self.ai.integrate1d(self.data, self.npt, filename=f.name)
-        self.assertGreater(os.path.getsize(f.name), 40)
-        f.close()
+        with resulttempfile() as filename:
+            self.ai.integrate1d(self.data, self.npt, filename=filename)
+            self.assertGreater(os.path.getsize(filename), 40)
 
     def test_defaultwriter(self):
-        f = tempfile.NamedTemporaryFile(delete=True)
-        self.assertEquals(os.path.getsize(f.name), 0)
-        result = self.ai.integrate1d(self.data, self.npt)
-        writer = DefaultAiWriter(f.name, self.ai)
-        writer.write(result)
-        writer.close()
-        self.assertGreater(os.path.getsize(f.name), 40)
-        f.close()
+        with resulttempfile() as filename:
+            result = self.ai.integrate1d(self.data, self.npt)
+            writer = DefaultAiWriter(filename, self.ai)
+            writer.write(result)
+            writer.close()
+            self.assertGreater(os.path.getsize(filename), 40)
 
 
 class TestIntegrate2D(unittest.TestCase):
@@ -137,6 +145,15 @@ class TestIntegrate2D(unittest.TestCase):
         cls.Rmax = 20
         cls.delta_pos_azim_max = 0.28
 
+    @classmethod
+    def tearDownClass(cls):
+        cls.npt = None
+        cls.img = None
+        cls.data = None
+        cls.ai = None
+        cls.Rmax = None
+        cls.delta_pos_azim_max = None
+
     def testQ(self):
         res = {}
         for m in ("numpy", "cython", "BBox", "splitpixel"):
@@ -199,21 +216,17 @@ class TestIntegrate2D(unittest.TestCase):
                 self.assertTrue(R <= self.Rmax, mesg)
 
     def test_filename(self):
-        f = tempfile.NamedTemporaryFile(delete=True)
-        self.assertEquals(os.path.getsize(f.name), 0)
-        self.ai.integrate2d(self.data, self.npt, filename=f.name)
-        self.assertGreater(os.path.getsize(f.name), 40)
-        f.close()
+        with resulttempfile() as filename:
+            self.ai.integrate2d(self.data, self.npt, filename=filename)
+            self.assertGreater(os.path.getsize(filename), 40)
 
     def test_defaultwriter(self):
-        f = tempfile.NamedTemporaryFile(delete=True)
-        self.assertEquals(os.path.getsize(f.name), 0)
-        result = self.ai.integrate2d(self.data, self.npt)
-        writer = DefaultAiWriter(f.name, self.ai)
-        writer.write(result)
-        writer.close()
-        self.assertGreater(os.path.getsize(f.name), 40)
-        f.close()
+        with resulttempfile() as filename:
+            result = self.ai.integrate2d(self.data, self.npt)
+            writer = DefaultAiWriter(filename, self.ai)
+            writer.write(result)
+            writer.close()
+            self.assertGreater(os.path.getsize(filename), 40)
 
 
 class TestIntegrateResult(unittest.TestCase):
@@ -224,6 +237,9 @@ class TestIntegrateResult(unittest.TestCase):
         self.azimuthal = numpy.array([[2, 2], [3, 4]])
         self.sigma = numpy.array([[4, 2], [3, 4]])
 
+    def tearDown(self):
+        self.I = self.radial = self.azimuthal = self.sigma = None
+
     def test_result_1d(self):
         result = Integrate1dResult(self.radial, self.I)
         # as tuple
@@ -284,12 +300,10 @@ class TestIntegrateResult(unittest.TestCase):
 
 def suite():
     testsuite = unittest.TestSuite()
-    testsuite.addTest(TestIntegrate1D("testQ"))
-    testsuite.addTest(TestIntegrate1D("testR"))
-    testsuite.addTest(TestIntegrate1D("test2th"))
-    testsuite.addTest(TestIntegrate2D("testQ"))
-    testsuite.addTest(TestIntegrate2D("testR"))
-    testsuite.addTest(TestIntegrate2D("test2th"))
+    loader = unittest.defaultTestLoader.loadTestsFromTestCase
+    testsuite.addTest(loader(TestIntegrate1D))
+    testsuite.addTest(loader(TestIntegrate2D))
+    testsuite.addTest(loader(TestIntegrateResult))
 
     return testsuite
 
