@@ -26,14 +26,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+"test suite for polarization corrections"
+
 from __future__ import absolute_import, division, print_function
 
-__doc__ = "test suite for polarization corrections"
 __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "28/11/2016"
+__date__ = "19/07/2017"
 
 
 import unittest
@@ -55,6 +56,7 @@ class TestPolarization(unittest.TestCase):
         self.ai = AzimuthalIntegrator(dist=1, pixel1=0.1, pixel2=0.1)
         self.ai._cached_array["2th_center"] = self.tth
         self.ai._cached_array["chi_center"] = chi
+        self.epsilon = 1e-15
 
     def tearDown(self):
         unittest.TestCase.tearDown(self)
@@ -66,34 +68,33 @@ class TestPolarization(unittest.TestCase):
 
     def testCircularPol(self):
         "Circular polarization should decay in (1+(cos2θ)^2)/2"
-        pol = (1.0 + numpy.cos(self.tth) ** 2) / 2.0
+        pol = ((1.0 + numpy.cos(self.tth) ** 2) / 2.0).astype("float32")
+        # print([abs(self.ai.polarization(factor=0, axis_offset=i) - pol).max() for i in range(6)])
         self.assertTrue(abs(self.ai.polarization(factor=0) - pol).max() == 0, "with circular polarization correction is independent of chi")
-        self.assertTrue(abs(self.ai.polarization(factor=0, axis_offset=1) - pol).max() == 0, "with circular polarization correction is independent of chi")
+        self.assertTrue(abs(self.ai.polarization(factor=0, axis_offset=1) - pol).max() == 0, "with circular polarization correction is independent of chi, 1")
+        self.assertTrue(abs(self.ai.polarization(factor=0, axis_offset=2) - pol).max() == 0, "with circular polarization correction is independent of chi, 2")
+        self.assertTrue(abs(self.ai.polarization(factor=0, axis_offset=3) - pol).max() == 0, "with circular polarization correction is independent of chi, 3")
 
     def testHorizPol(self):
         "horizontal polarization should decay in (cos2θ)**2 in horizontal plane and no correction in vertical one"
         self.assertTrue(abs(self.ai.polarization(factor=1)[:, 6] - numpy.ones(13)).max() == 0, "No correction in the vertical plane")
-        self.assertTrue(abs(self.ai.polarization(factor=1)[6] - numpy.cos(self.rotX) ** 2).max() < 1e-15, "cos(2th)^2 like in the horizontal plane")
+        self.assertTrue(abs(self.ai.polarization(factor=1)[6] - numpy.cos(self.rotX) ** 2).max() < self.epsilon, "cos(2th)^2 like in the horizontal plane")
 
     def testVertPol(self):
         "Vertical polarization should decay in (cos2θ)**2 in vertical plane and no correction in horizontal one"
         self.assertTrue(abs(self.ai.polarization(factor=-1)[6] - numpy.ones(13)).max() == 0, "No correction in the horizontal plane")
-        self.assertTrue(abs(self.ai.polarization(factor=-1)[:, 6] - (numpy.cos((2 * self.rotX)) + 1) / 2).max() < 1e-15, "cos(2th)^2 like in the verical plane")
+        self.assertTrue(abs(self.ai.polarization(factor=-1)[:, 6] - (numpy.cos((2 * self.rotX)) + 1) / 2).max() < self.epsilon, "cos(2th)^2 like in the verical plane")
 
     def testoffsetPol(self):
         "test for the rotation of the polarization axis"
         self.assertTrue(abs(self.ai.polarization(factor=1, axis_offset=numpy.pi / 2)[6] - numpy.ones(13)).max() == 0, "No correction in the horizontal plane")
-        self.assertTrue(abs(self.ai.polarization(factor=1, axis_offset=numpy.pi / 2)[:, 6] - (numpy.cos((2 * self.rotX)) + 1) / 2).max() < 1e-15, "cos(2th)^2 like in the verical plane")
+        self.assertTrue(abs(self.ai.polarization(factor=1, axis_offset=numpy.pi / 2)[:, 6] - (numpy.cos((2 * self.rotX)) + 1) / 2).max() < self.epsilon, "cos(2th)^2 like in the verical plane")
 
 
 def suite():
+    loader = unittest.defaultTestLoader.loadTestsFromTestCase
     testsuite = unittest.TestSuite()
-    testsuite.addTest(TestPolarization("testNoPol"))
-    testsuite.addTest(TestPolarization("testCircularPol"))
-    testsuite.addTest(TestPolarization("testHorizPol"))
-    testsuite.addTest(TestPolarization("testVertPol"))
-    testsuite.addTest(TestPolarization("testoffsetPol"))
-    # testsuite.addTest(TestPolarization("test2th"))
+    testsuite.addTest(loader(TestPolarization))
     return testsuite
 
 
